<?php

namespace Teknisa\DF\Modules\Saida\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;


class Dfs74000CalculoReceitaBrutaSimplesNacionalFactory{
    protected $connection;
    protected $entityManager;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function buscaMesPosterior($nrorg,$cdempresa,$cdsimplesnacional,$dtreferencia){
        $sql = "SELECT CDEMPRESA, DTREFRECEITABR, IDSTATUSMES, VRRECEITABR, VRSALDONEGMES, VRSALDODEDUZ, VRSALDOCOMPOE, CDSIMPLESNACIONAL
                FROM RECEITABRUTA
                WHERE CDEMPRESA                           = :P_CDEMPRESA
                    AND CDSIMPLESNACIONAL                     = :P_TABELASN
                    AND DTREFRECEITABR > TO_DATE(:P_DTREFERENCIA, 'DD/MM/YYYY') + 1
                    AND IDSTATUSMES                          IN ('B', 'C')
                    AND NRORG                                 =:P_NRORG
                    ORDER BY DTREFRECEITABR ";

        $params = array(
           'P_NRORG'=>$nrorg,
           'P_CDEMPRESA'=>$cdempresa,
           'P_TABELASN'=>$cdsimplesnacional,
           'P_DTREFERENCIA'=>$dtreferencia
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    public function buscaMesAtual($nrorg,$cdempresa,$cdsimplesnacional,$dtreferencia){
        $sql = "SELECT CDEMPRESA, DTREFRECEITABR, IDSTATUSMES, VRRECEITABR, VRSALDONEGMES, VRSALDODEDUZ, VRSALDOCOMPOE, CDSIMPLESNACIONAL
                FROM RECEITABRUTA
                WHERE CDEMPRESA                           = :P_CDEMPRESA
                    AND CDSIMPLESNACIONAL                     = :P_TABELASN
                    AND TO_CHAR(DTREFRECEITABR,'DD/MM/YYYY') = :P_DTREFERENCIA
                    AND NRORG                                 =:P_NRORG
                    ORDER BY DTREFRECEITABR ";

        $params = array(
           'P_NRORG'=>$nrorg,
           'P_CDEMPRESA'=>$cdempresa,
           'P_TABELASN'=>$cdsimplesnacional,
           'P_DTREFERENCIA'=>$dtreferencia
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }


    public function calculaReceitaBrutaMes($cdempresa,$idtratrecbruta,$cdsimplesnacional,$dtreferencia){
        $sql = "SELECT SUM(NVL(VRNOTAFISC,0)) AS VRNOTAFISC
                FROM (
                   SELECT SUM(NVL(I.VRBRUTITEM,0) - NVL(VALOR_IMPOSTO_ITEM_NFE(I.CDFILIAL, I.NRLANCTONF, I.NRSEQITPROD,'80','I','1'),0)) AS VRNOTAFISC
                     FROM ITEMPRODUTO I, NOTAFISCAL N,
                          (SELECT CDTIPOOPER,
                            IDENTRSAIDOP
                          FROM TPOPERSIMPLESNAC
                          WHERE IDTIPOOPERREC = :P_IDTRATRECBRUTA
                            AND CDSIMPLESNACIONAL = :P_TABELASN
                          ) T
                    WHERE N.CDEMPRESA  = :P_CDEMPRESA
                        AND N.CDTIPOOPER   = T.CDTIPOOPER
                        AND N.IDENTRSAIDOP = T.IDENTRSAIDOP
                        AND N.DTENTRSAID BETWEEN TRUNC(TO_DATE(:P_DTREFERENCIA), 'MONTH') AND LAST_DAY(TO_DATE(:P_DTREFERENCIA))
                        AND N.IDENTRSAIDOP = 'E'
                        AND N.IDSTATUS              IN ('E','A')
                        AND NVL(N.IDSISTEMA, 'DFS') <> 'ITG'
                        AND NVL(N.IDSISTEMA, 'DFS') <> 'REC'
                        AND NVL(N.IDSISTEMA, 'DFS') <> 'PAG'
                        AND NVL(N.IDSISTEMA, 'DFS') <> 'TMP'
                        AND I.CDFILIAL     = N.CDFILIAL
                        AND I.NRLANCTONF   = N.NRLANCTONF
                        AND I.CDSIMPLESNACIONAL = :P_TABELASN
                   UNION ALL
                   SELECT SUM(NVL(I.VRBRUTITEM,0) - NVL(VALOR_IMPOSTO_ITEM_NFE(I.CDFILIAL, I.NRLANCTONF, I.NRSEQITPROD,'80','I','1'),0)) AS VRNOTAFISC
                     FROM ITEMPRODUTO I, NOTAFISCAL N,
                          (SELECT CDTIPOOPER,
                            IDENTRSAIDOP
                          FROM TPOPERSIMPLESNAC
                          WHERE IDTIPOOPERREC = :P_IDTRATRECBRUTA
                            AND CDSIMPLESNACIONAL = :P_TABELASN
                          ) T
                   WHERE N.CDEMPRESA  = :P_CDEMPRESA
                     AND N.CDTIPOOPER   = T.CDTIPOOPER
                     AND N.IDENTRSAIDOP = T.IDENTRSAIDOP
                     AND N.DTEMISSAO BETWEEN TRUNC(TO_DATE(:P_DTREFERENCIA), 'MONTH') AND LAST_DAY(TO_DATE(:P_DTREFERENCIA))
                     AND N.IDENTRSAIDOP = 'S'
                     AND N.IDSTATUS              IN ('E','A')
                     AND NVL(N.IDSISTEMA, 'DFS') <> 'ITG'
                     AND NVL(N.IDSISTEMA, 'DFS') <> 'REC'
                     AND NVL(N.IDSISTEMA, 'DFS') <> 'PAG'
                     AND NVL(N.IDSISTEMA, 'DFS') <> 'TMP'
                     AND I.CDFILIAL     = N.CDFILIAL
                     AND I.NRLANCTONF   = N.NRLANCTONF
                     AND I.CDSIMPLESNACIONAL = :P_TABELASN
                     AND ((LENGTH(I.CDFISCOPERSN) = 3 AND I.CDFISCOPERSN <> '400') OR
                          (LENGTH(I.CDFISCOPERSN) = 4 AND NVL(RTRIM(SUBSTR(I.CDFISCOPERSN,2,3)),'0') <> '400'))
                   UNION ALL
                   SELECT NVL(SUM(VRNOTAFISC), 0) AS VRNOTAFISC
                     FROM NOTAFISCAL N,
                          (SELECT CDTIPOOPER,
                            IDENTRSAIDOP
                          FROM TPOPERSIMPLESNAC
                          WHERE IDTIPOOPERREC = :P_IDTRATRECBRUTA
                            AND CDSIMPLESNACIONAL = :P_TABELASN
                          ) T
                   WHERE N.CDEMPRESA  = :P_CDEMPRESA
                     AND N.CDTIPOOPER   = T.CDTIPOOPER
                     AND N.IDENTRSAIDOP = T.IDENTRSAIDOP
                     AND N.DTENTRSAID BETWEEN TRUNC(TO_DATE(:P_DTREFERENCIA), 'MONTH') AND LAST_DAY(TO_DATE(:P_DTREFERENCIA))
                     AND N.IDSTATUS              IN ('E','A')
                     AND NVL(N.IDSISTEMA, 'DFS') = 'FIS'
                )";
        $params = array(
           'P_CDEMPRESA'=>$cdempresa,
           'P_IDTRATRECBRUTA'=>$idtratrecbruta,
           'P_TABELASN'=>$cdsimplesnacional,
           'P_DTREFERENCIA'=>$dtreferencia
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function atualizaReceitaBruta ($idstatusmes, $vrreceitabr, $vrsaldocompoe, $vrsaldonegmes, $vrsaldodeduz, $idinfmanual,$cdempresa, $cdsimplesnacional, $dtrefreceitabr, $nrorg){
        $params               = array();

        $params['IDSTATUSMES']       = $idstatusmes;
        $params['VRRECEITABR']       = $vrreceitabr;
        $params['VRSALDOCOMPOE']     = $vrsaldocompoe;
        $params['VRSALDONEGMES']     = $vrsaldonegmes;
        $params['VRSALDODEDUZ']      = $vrsaldodeduz;
        $params['IDINFMANUAL']       = $idinfmanual;
        $params['CDEMPRESA']         = $cdempresa;
        $params['CDSIMPLESNACIONAL'] = $cdsimplesnacional;
        $params['DTREFRECEITABR']    = $dtrefreceitabr;
        $params['NRORG']             = $nrorg;
        $sql = "UPDATE RECEITABRUTA
                    SET IDSTATUSMES = :IDSTATUSMES,
                    VRRECEITABR     = :VRRECEITABR,
                    VRSALDOCOMPOE   = :VRSALDOCOMPOE,
                    VRSALDONEGMES   = :VRSALDONEGMES,
                    VRSALDODEDUZ    = :VRSALDODEDUZ,
                    IDINFMANUAL     = :IDINFMANUAL
                WHERE CDEMPRESA           = :CDEMPRESA
                    AND CDSIMPLESNACIONAL = :CDSIMPLESNACIONAL
                    AND DTREFRECEITABR    = :DTREFRECEITABR
                    AND NRORG             = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function buscaNotasFiscaisMes($cdempresa,$cdsimplesnacional,$dtreferencia){
        $sql =  "SELECT CDFILIAL, NRLANCTONF
                    FROM NOTAFISCAL N,
                        (SELECT CDTIPOOPER, IDENTRSAIDOP
                            FROM TPOPERSIMPLESNAC
                            WHERE CDSIMPLESNACIONAL = :P_TABELASN
                        ) T
                    WHERE N.CDEMPRESA  = :P_CDEMPRESA
                        AND N.CDTIPOOPER   = T.CDTIPOOPER
                        AND N.IDENTRSAIDOP = T.IDENTRSAIDOP
                        AND N.DTENTRSAID BETWEEN TRUNC(TO_DATE(:P_DTREFERENCIA), 'MONTH') AND LAST_DAY(TO_DATE(:P_DTREFERENCIA))
                        AND N.IDSTATUS IN ('E','A') ";
        $params = array(
           'P_CDEMPRESA'=>$cdempresa,
           'P_TABELASN'=>$cdsimplesnacional,
           'P_DTREFERENCIA'=>$dtreferencia
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function atualizaNotaFiscal ($dtreferencia, $cdfilial, $nrlanctonf){
        $params               = array();

        $params['P_DTREFERENCIA'] = $dtreferencia;
        $params['P_CDFILIAL']     = $cdfilial;
        $params['P_NRLANCTONF']   = $nrlanctonf;
        $sql = "UPDATE NOTAFISCAL
                    SET DTCALCRECBRUTA = TRUNC(TO_DATE(:P_DTREFERENCIA), 'MONTH')
                    WHERE CDFILIAL   = :P_CDFILIAL
                      AND NRLANCTONF = :P_NRLANCTONF";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function buscaSaldoNegativoMesAnterior($cdempresa,$cdsimplesnacional,$dtreferencia){
        $sql = "SELECT NVL(VRSALDONEGMES, 0) VRSALDONEGMES,DTREFRECEITABR
                    FROM RECEITABRUTA
                    WHERE CDEMPRESA    = :P_CDEMPRESA
                        AND CDSIMPLESNACIONAL = :P_TABELASN
                        AND DTREFRECEITABR =
                            (SELECT MAX(DTREFRECEITABR)
                                FROM RECEITABRUTA
                                WHERE CDEMPRESA                        = :P_CDEMPRESA
                                AND DTREFRECEITABR < :P_DTREFERENCIA
                            )";
        $params = array(
           'P_CDEMPRESA'=>$cdempresa,
           'P_TABELASN'=>$cdsimplesnacional,
           'P_DTREFERENCIA'=>$dtreferencia
        );
        //var_dump($params);die;
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

}